@@ -14,17 +14,16 @@ import re
 import pytest
 import rx
 from dependency_injector import providers
-from krules_core.base_functions.filters import Returns, CheckSubjectProperty, CheckSubjectExtendedProperty, \
-    CheckStoredSubjectProperty, CheckPayloadMatch, CheckSubjectMatch, CheckSubjectDoesNotMatch, IsTrue, IsFalse, \
-    CheckPayloadMatchOne, OnSubjectPropertyChanged
+from krules_core.base_functions.filters import Returns, CheckSubjectProperty, PayloadMatch, SubjectNameMatch, \
+    SubjectNameDoesNotMatch, IsTrue, IsFalse, PayloadMatchOne, SubjectPropertyChanged
 
 from krules_core import RuleConst
 
 from krules_core.core import RuleFactory
 
 from krules_core.providers import (
-    message_router_factory,
-    results_rx_factory,
+    event_router_factory,
+    proc_events_rx_factory,
     subject_factory,
 )
 
@@ -41,11 +40,11 @@ def subject():
 
 @pytest.fixture
 def router():
-    router = message_router_factory()
+    router = event_router_factory()
     router.unregister_all()
-    results_rx_factory.override(providers.Singleton(rx.subjects.ReplaySubject))
+    proc_events_rx_factory.override(providers.Singleton(rx.subjects.ReplaySubject))
 
-    return message_router_factory()
+    return event_router_factory()
 
 @pytest.fixture
 def asserted():
@@ -56,7 +55,7 @@ def asserted():
 
 filters = RuleConst.FILTERS
 processing = RuleConst.PROCESSING
-rule_name = RuleConst.RULE_NAME
+rulename = RuleConst.RULENAME
 processed = RuleConst.PROCESSED
 
 
@@ -70,14 +69,14 @@ def test_return(subject, router, asserted):
 
     RuleFactory.create('test-returns',
                        subscribe_to="event-test-returns",
-                       ruledata={
+                       data={
                            filters: [
                                Returns("something"),
                            ],
                        })
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == 'test-returns' and _assert(
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == 'test-returns' and _assert(
             'test-returns-something',
             x[processed] and x[filters][0]["returns"] == "something"
             )
@@ -93,7 +92,7 @@ def test_truth(subject, router, asserted):
 
     RuleFactory.create('test-is-true',
                        subscribe_to="event-test-truth",
-                       ruledata={
+                       data={
                            filters: [
                                IsTrue(
                                     lambda payload: payload["it-works"]
@@ -103,7 +102,7 @@ def test_truth(subject, router, asserted):
 
     RuleFactory.create('test-is-false',
                        subscribe_to="event-test-truth",
-                       ruledata={
+                       data={
                            filters: [
                                IsFalse(
                                    lambda payload: payload["it-works"] is False
@@ -111,14 +110,14 @@ def test_truth(subject, router, asserted):
                            ],
                        })
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == 'test-is-true' and _assert(
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == 'test-is-true' and _assert(
             'test-is-true',
             x[processed] and x[filters][0]["returns"] is True
             )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == 'test-is-false' and _assert(
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == 'test-is-false' and _assert(
             'test-is-false',
             x[processed] and x[filters][0]["returns"] is True
             )
@@ -137,9 +136,9 @@ def test_subject_match(router, asserted):
 
     RuleFactory.create('test-subject-match',
                        subscribe_to='event-user-action',
-                       ruledata={
+                       data={
                            filters: [
-                               CheckSubjectMatch(r"^user\|(?P<user_id>.+)", payload_dest="user_info"),
+                               SubjectNameMatch(r"^user\|(?P<user_id>.+)", payload_dest="user_info"),
                                IsTrue(
                                    lambda payload: "user_id" in payload.get("user_info", {})
                                )
@@ -148,20 +147,20 @@ def test_subject_match(router, asserted):
 
     RuleFactory.create('test-subject-does-not-match',
                        subscribe_to='event-user-action',
-                       ruledata={
+                       data={
                            filters: [
-                               CheckSubjectDoesNotMatch(r"^device\|(?P<device_id>.+)", payload_dest="device_info"),
+                               SubjectNameDoesNotMatch(r"^device\|(?P<device_id>.+)", payload_dest="device_info"),
                            ]
                        })
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == 'test-subject-match' and _assert(
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == 'test-subject-match' and _assert(
             'test-subject-match',
             x[processed] is True
             )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == 'test-subject-does-not-match' and _assert(
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == 'test-subject-does-not-match' and _assert(
             'test-subject-does-not-match',
             x[processed] is True
             )
@@ -178,7 +177,7 @@ def test_check_subject_property(router, subject, asserted):
     RuleFactory.create(
         "test-simple-subject-property",
         subscribe_to="test-subject-property",
-        ruledata={
+        data={
             filters: [
                 CheckSubjectProperty("prop-1", "value-1"),
                 CheckSubjectProperty("prop-2", 2),
@@ -189,7 +188,7 @@ def test_check_subject_property(router, subject, asserted):
     RuleFactory.create(
         "test-simple-subject-property-fails",
         subscribe_to="test-subject-property",
-        ruledata={
+        data={
             filters: [
                 CheckSubjectProperty("prop-1", "value-1"),
                 CheckSubjectProperty("prop-2", "2"),
@@ -201,13 +200,13 @@ def test_check_subject_property(router, subject, asserted):
     RuleFactory.create(
         "test-expr-subject-property",
         subscribe_to="test-subject-property",
-        ruledata={
+        data={
             filters: [
                 # one argument (value)
                 CheckSubjectProperty("prop-1"),
                 CheckSubjectProperty("prop-1", lambda v: v in ("value-1",) and re.match("value-[0-9]", v)),
                 CheckSubjectProperty("prop-2", lambda v: type(v) is int),
-                CheckSubjectExtendedProperty("ext-prop")
+                CheckSubjectProperty("ext-prop", extended=True)
             ]
         }
     )
@@ -216,15 +215,15 @@ def test_check_subject_property(router, subject, asserted):
     subject.set("prop-2", 2)
     subject.set_ext("ext-prop-2", "extprop")
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-simple-subject-property" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-simple-subject-property" and _assert(
+            x[rulename],
             x[processed] is True
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-simple-subject-property-fails" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-simple-subject-property-fails" and _assert(
+            x[rulename],
             x[processed] is False
         )
     )
@@ -236,7 +235,7 @@ def test_check_subject_property(router, subject, asserted):
 
     # clean up
     router.unregister_all()
-    results_rx_factory.override(providers.Singleton(rx.subjects.ReplaySubject))
+    proc_events_rx_factory.override(providers.Singleton(rx.subjects.ReplaySubject))
 
     # check direct
     subject.set("prop-1", "value-2")
@@ -246,9 +245,9 @@ def test_check_subject_property(router, subject, asserted):
     RuleFactory.create(
         "test-subject-property-direct",
         subscribe_to="test-subject-property-direct",
-        ruledata={
+        data={
             filters: [
-                CheckStoredSubjectProperty("v-prop-1", "value-2"),  # prop-1 is still value-1
+                CheckSubjectProperty("v-prop-1", "value-2", cached=False),  # prop-1 is still value-1
             ]
         }
     )
@@ -256,23 +255,23 @@ def test_check_subject_property(router, subject, asserted):
     RuleFactory.create(
         "test-subject-property-ext-direct",
         subscribe_to="test-subject-property-direct",
-        ruledata={
+        data={
             filters: [
-                CheckStoredSubjectProperty("ext-prop-3"),  # ext-prop-3 does not exists yet
+                CheckSubjectProperty("ext-prop-3", cached=False),  # ext-prop-3 does not exists yet
             ]
         }
     )
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-subject-property-direct" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-subject-property-direct" and _assert(
+            x[rulename],
             not x[processed]
         )
     )
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-subject-property-ext-direct" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-subject-property-ext-direct" and _assert(
+            x[rulename],
             not x[processed]
         )
     )
@@ -318,9 +317,9 @@ def test_check_payload_match(router, subject, asserted):
     RuleFactory.create(
         "test-check-payload-jpmatch-not-empty",
         subscribe_to="test-check-payload-jpmatch",
-        ruledata={
+        data={
             filters: [
-                CheckPayloadMatch("$..batch_data[?@.value>100]")  # returns two elements - pass
+                PayloadMatch("$..batch_data[?@.value>100]")  # returns two elements - pass
             ]
         }
     )
@@ -328,10 +327,10 @@ def test_check_payload_match(router, subject, asserted):
     RuleFactory.create(
         "test-check-payload-jpmatch-store-result",
         subscribe_to="test-check-payload-jpmatch",
-        ruledata={
+        data={
             filters: [
-                CheckPayloadMatch("$.batch_data[?@.value>100]", lambda m: len(m) == 2),
-                CheckPayloadMatch("$.batch_data[?@.value>100]", payload_dest="jpexpr_match"),
+                PayloadMatch("$.batch_data[?@.value>100]", lambda m: len(m) == 2),
+                PayloadMatch("$.batch_data[?@.value>100]", payload_dest="jpexpr_match"),
                 IsTrue(
                     lambda payload: len(payload['jpexpr_match']) == 2
                 )
@@ -342,11 +341,11 @@ def test_check_payload_match(router, subject, asserted):
     RuleFactory.create(
         "test-check-payload-jpmatch-one",
         subscribe_to="test-check-payload-jpmatch",
-        ruledata={
+        data={
             filters: [
-                CheckPayloadMatchOne("$.device_info.id", "0AFB1110"),
-                CheckPayloadMatchOne("$.device_info.id", payload_dest="device_id"),
-                CheckPayloadMatchOne("$.device.info.disabled", lambda disabled: not disabled),
+                PayloadMatchOne("$.device_info.id", "0AFB1110"),
+                PayloadMatchOne("$.device_info.id", payload_dest="device_id"),
+                PayloadMatchOne("$.device.info.disabled", lambda disabled: not disabled),
                 IsTrue(
                     lambda payload: payload["device_id"] == "0AFB1110"
                 )
@@ -354,24 +353,27 @@ def test_check_payload_match(router, subject, asserted):
         }
     )
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-check-payload-jpmatch-not-empty" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-check-payload-jpmatch-not-empty" and _assert(
+            x[rulename],
             x[processed]
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-check-payload-jpmatch-store-result" and _assert(
-            x[rule_name],
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-check-payload-jpmatch-store-result" and _assert(
+            x[rulename],
             x[processed]
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-check-payload-jpmatch-one" and _assert(
-           x[rule_name],
-           x[processed]
-       )
-   )
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-check-payload-jpmatch-one" and _assert(
+            x[rulename],
+            x[processed]
+            and x[filters][0]["returns"] is True
+            and x[filters][1]["returns"] is True
+            and x[filters][2]["returns"] is True
+        )
+    )
 
     router.route("test-check-payload-jpmatch", subject, payload)
 
@@ -382,89 +384,89 @@ def test_check_payload_match(router, subject, asserted):
 
 def test_on_subject_property_changed(router, subject, asserted):
 
-    from krules_core import messages
+    from krules_core import types
     RuleFactory.create(
         "test-prop-changed",
-        subscribe_to=messages.SUBJECT_PROPERTY_CHANGED,
-        ruledata={
+        subscribe_to=types.SUBJECT_PROPERTY_CHANGED,
+        data={
             filters: [
-                OnSubjectPropertyChanged("prop_a"),
-                OnSubjectPropertyChanged(lambda: "prop_{}".format("a")),
-                OnSubjectPropertyChanged(lambda prop: re.match("prop_[a-z]", prop)),
-                OnSubjectPropertyChanged("prop_a", lambda: 1),
-                OnSubjectPropertyChanged("prop_a", value=lambda value: value > 0),
-                OnSubjectPropertyChanged("prop_a", value=lambda value, old_value: value == 1 and old_value is None),
-                OnSubjectPropertyChanged("prop_a", old_value=None),
-                OnSubjectPropertyChanged("prop_a", old_value=lambda old_value: old_value is None)
+                SubjectPropertyChanged("prop_a"),
+                SubjectPropertyChanged(lambda: "prop_{}".format("a")),
+                SubjectPropertyChanged(lambda prop: re.match("prop_[a-z]", prop)),
+                SubjectPropertyChanged("prop_a", lambda: 1),
+                SubjectPropertyChanged("prop_a", value=lambda value: value > 0),
+                SubjectPropertyChanged("prop_a", value=lambda value, old_value: value == 1 and old_value is None),
+                SubjectPropertyChanged("prop_a", old_value=None),
+                SubjectPropertyChanged("prop_a", old_value=lambda old_value: old_value is None)
            ]
         }
     )
     RuleFactory.create(
         "test-prop-changed-fails-1",
-        subscribe_to=messages.SUBJECT_PROPERTY_CHANGED,
-        ruledata={
+        subscribe_to=types.SUBJECT_PROPERTY_CHANGED,
+        data={
             filters: [
-                OnSubjectPropertyChanged("prop_b"),
+                SubjectPropertyChanged("prop_b"),
            ]
         }
     )
     RuleFactory.create(
         "test-prop-changed-fails-2",
-        subscribe_to=messages.SUBJECT_PROPERTY_CHANGED,
-        ruledata={
+        subscribe_to=types.SUBJECT_PROPERTY_CHANGED,
+        data={
             filters: [
-                OnSubjectPropertyChanged("prop_a", lambda value: value > 1),
+                SubjectPropertyChanged("prop_a", lambda value: value > 1),
             ]
         }
     )
     RuleFactory.create(
         "test-prop-changed-fails-3",
-        subscribe_to=messages.SUBJECT_PROPERTY_CHANGED,
-        ruledata={
+        subscribe_to=types.SUBJECT_PROPERTY_CHANGED,
+        data={
             filters: [
-                OnSubjectPropertyChanged("prop_a", lambda value, old_value: value == 1 and old_value is not None),
+                SubjectPropertyChanged("prop_a", lambda value, old_value: value == 1 and old_value is not None),
             ]
         }
     )
     RuleFactory.create(
         "test-prop-changed-fails-4",
-        subscribe_to=messages.SUBJECT_PROPERTY_CHANGED,
-        ruledata={
+        subscribe_to=types.SUBJECT_PROPERTY_CHANGED,
+        data={
             filters: [
-                OnSubjectPropertyChanged("prop_a", lambda value, old_value: value == 1,
+                SubjectPropertyChanged("prop_a", lambda value, old_value: value == 1,
                                          lambda old_value: old_value is not None),
             ]
         }
     )
 
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-prop-changed" and _assert(
-            x[rule_name],
-            x[processed], "{} not processed".format(x[rule_name])
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-prop-changed" and _assert(
+            x[rulename],
+            x[processed], "{} not processed".format(x[rulename])
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-prop-changed-fails-1" and _assert(
-            x[rule_name],
-            not x[processed], "{} should not be not processed".format(x[rule_name])
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-prop-changed-fails-1" and _assert(
+            x[rulename],
+            not x[processed], "{} should not be not processed".format(x[rulename])
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-prop-changed-fails-2" and _assert(
-            x[rule_name],
-            not x[processed], "{} should not be not processed".format(x[rule_name])
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-prop-changed-fails-2" and _assert(
+            x[rulename],
+            not x[processed], "{} should not be not processed".format(x[rulename])
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-prop-changed-fails-3" and _assert(
-            x[rule_name],
-            not x[processed], "{} should not be not processed".format(x[rule_name])
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-prop-changed-fails-3" and _assert(
+            x[rulename],
+            not x[processed], "{} should not be not processed".format(x[rulename])
         )
     )
-    results_rx_factory().subscribe(
-        lambda x: x[rule_name] == "test-prop-changed-fails-4" and _assert(
-            x[rule_name],
-            not x[processed], "{} should not be not processed".format(x[rule_name])
+    proc_events_rx_factory().subscribe(
+        lambda x: x[rulename] == "test-prop-changed-fails-4" and _assert(
+            x[rulename],
+            not x[processed], "{} should not be not processed".format(x[rulename])
         )
     )
 
