@@ -9,7 +9,7 @@ from krules_core.tests.subject.sqlite_storage import SQLLiteSubjectStorage
 def test_memorydatabase():
 
     subject_storage_factory.override(
-        providers.Factory(lambda x: SQLLiteSubjectStorage(x, ":memory:"))
+        providers.Factory(lambda x, **kwargs: SQLLiteSubjectStorage(x, ":memory:"))
     )
     assert not subject_storage_factory("test-subject").is_persistent()
     assert not subject_storage_factory("test-subject").is_concurrency_safe()
